@@ -21,7 +21,7 @@ pub struct ColorDetailedInfoObject {
     hue: u32,
     saturation: f32,
     lightness: f32,
-    rgb: [u32;3],
+    rgb: [u32; 3],
 }
 
 pub struct Colors;
@@ -44,19 +44,20 @@ impl EndPointIds for Colors {
 
 #[cfg(test)]
 mod tests {
-    use ureq::Agent;
+    use reqwest::Client;
 
     use crate::end_point::{EndPoint, EndPointIds};
 
     use super::Colors;
 
-    #[test]
-    fn check_world() {
-        let agent = Agent::new();
-        let result = Colors::get(agent.clone()).unwrap();
+    #[tokio::test]
+    async fn check_color() -> anyhow::Result<()> {
+        let client = Client::new();
+        let result = Colors::get(client.clone()).await?;
         assert_eq!(
             result[0],
-            Colors::get_with_id(agent, &[result[0]]).unwrap()[0].id
-        )
+            Colors::get_with_id(client, &[result[0]]).await?[0].id
+        );
+        Ok(())
     }
 }
