@@ -26,19 +26,21 @@ impl EndPointIds for Dailycrafting {
 
 #[cfg(test)]
 mod tests {
-    use ureq::Agent;
+    use reqwest::Client;
 
     use crate::end_point::{EndPoint, EndPointIds};
 
     use super::Dailycrafting;
 
-    #[test]
-    fn check_world() {
-        let agent = Agent::new();
-        let result = Dailycrafting::get(agent.clone()).unwrap();
+    #[tokio::test]
+    async fn check_dailycrafting() -> anyhow::Result<()> {
+        let client = Client::new();
+        let result = Dailycrafting::get(client.clone()).await?;
         assert_eq!(
             result[0],
-            Dailycrafting::get_with_id(agent, &[result[0].clone()]).unwrap()[0].id
-        )
+            Dailycrafting::get_with_id(client, &[result[0].clone()]).await?[0].id
+        );
+
+        Ok(())
     }
 }
