@@ -12,7 +12,7 @@ pub struct Item {
     name: String,
     icon: Option<Url>,
     description: Option<String>,
-    #[serde(rename="type")]
+    #[serde(rename = "type")]
     t: String,
     rarity: String,
     level: u32,
@@ -24,12 +24,11 @@ pub struct Item {
     upgrades_into: Option<Vec<ItemUpgrade>>,
     upgrades_from: Option<Vec<ItemUpgrade>>,
     details: serde_json::Value,
-
 }
 #[derive(serde::Serialize, serde::Deserialize)]
 pub struct ItemUpgrade {
     upgrade: String,
-    item_id: ItemId
+    item_id: ItemId,
 }
 
 pub struct Items;
@@ -52,19 +51,16 @@ impl EndPointIds for Items {
 
 #[cfg(test)]
 mod tests {
-    use ureq::Agent;
+    use reqwest::Client;
 
     use crate::end_point::{EndPoint, EndPointIds};
 
     use super::Items;
 
-    #[test]
-    fn check_world() {
-        let agent = Agent::new();
-        let result = Items::get(agent.clone()).unwrap();
-        assert_eq!(
-            result[0],
-            Items::get_with_id(agent, &[result[0]]).unwrap()[0].id
-        )
+    #[tokio::test]
+    async fn check_item() {
+        let client = Client::new();
+        let result = Items::get(client.clone()).await.unwrap();
+        assert_eq!(result[0], Items::get_with_id(client, &[result[0]]).await.unwrap()[0].id);
     }
 }
