@@ -32,19 +32,20 @@ impl EndPointIds for Outfits {
 
 #[cfg(test)]
 mod tests {
-    use ureq::Agent;
+    use reqwest::Client;
 
     use crate::end_point::{EndPoint, EndPointIds};
 
     use super::Outfits;
 
-    #[test]
-    fn check_world() {
-        let agent = Agent::new();
-        let result = Outfits::get(agent.clone()).unwrap();
+    #[tokio::test]
+    async fn check_outfit() -> anyhow::Result<()> {
+        let client = Client::new();
+        let result = Outfits::get(client.clone()).await?;
         assert_eq!(
             result[0],
-            Outfits::get_with_id(agent, &[result[0]]).unwrap()[0].id
-        )
+            Outfits::get_with_id(client, &[result[0]]).await?[0].id
+        );
+        Ok(())
     }
 }
