@@ -29,19 +29,19 @@ impl EndPointIds for Quaggans {
 
 #[cfg(test)]
 mod tests {
-    use ureq::Agent;
+    use reqwest::Client;
 
     use crate::end_point::{EndPoint, EndPointIds};
 
     use super::Quaggans;
 
-    #[test]
-    fn check_quaggan() {
-        let agent = Agent::new();
-        let result = Quaggans::get(agent.clone()).unwrap();
+    #[tokio::test]
+    async fn check_quaggan()  {
+        let client = Client::new();
+        let result = Quaggans::get(client.clone()).await.unwrap();
         assert_eq!(
             result[0],
-            Quaggans::get_with_id(agent, &[result[0].clone()]).unwrap()[0].id
-        )
+            Quaggans::get_with_id(client, &[result[0].clone()]).await.unwrap()[0].id
+        );
     }
 }
