@@ -34,16 +34,16 @@ impl EndPointIds for Worlds {
 
 #[cfg(test)]
 mod tests {
-    use ureq::Agent;
+    use reqwest::Client;
 
     use crate::end_point::{EndPoint, EndPointIds};
 
     use super::Worlds;
 
-    #[test]
-    fn check_world() {
-        let agent = Agent::new();
-        let result = Worlds::get(agent.clone()).unwrap();
-        assert_eq!(result[0], Worlds::get_with_id(agent, &[result[0]]).unwrap()[0].id )
+    #[tokio::test]
+    async fn check_world() {
+        let client = Client::new();
+        let result = Worlds::get(client.clone()).await.unwrap();
+        assert_eq!(result[0], Worlds::get_with_id(client, &[result[0]]).await.unwrap()[0].id )
     }
 }
