@@ -5,10 +5,13 @@ api->builder
     endpoints()
 
 enum endpoint
-
-
 */
 
-mod end_point;
+pub mod end_point;
 const API_BASE_URL: &str = "https://api.guildwars2.com";
-const API_BASE_V2_URL: &str = const_format::concatcp!(API_BASE_URL, "/v2");
\ No newline at end of file
+const API_BASE_V2_URL: &str = const_format::concatcp!(API_BASE_URL, "/v2");
+
+// Make sure to set the following options when you create client
+// user_agent
+// https only
+// 
\ No newline at end of file
